
sncosmo.SALT2Model
==================

.. currentmodule:: sncosmo

.. autoclass:: SALT2Model
   :show-inheritance:

   
   
   .. rubric:: Attributes

   .. autosummary::
   
         cosmo
         params
         parnames
         refband
         refmagsys
         refphase
   
   


   
   
   .. rubric:: Methods Summary

   .. autosummary::
   
      ~SALT2Model.__call__
      ~SALT2Model.bandflux
      ~SALT2Model.bandmag
      ~SALT2Model.bandoverlap
      ~SALT2Model.disp
      ~SALT2Model.flux
      ~SALT2Model.set
      ~SALT2Model.set_bandflux_relative_error
      ~SALT2Model.times
   
   


   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: __call__
   .. automethod:: bandflux
   .. automethod:: bandmag
   .. automethod:: bandoverlap
   .. automethod:: disp
   .. automethod:: flux
   .. automethod:: set
   .. automethod:: set_bandflux_relative_error
   .. automethod:: times

   
   